<?php

namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Util\SupUtilities;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Cmp02600ParticularidadesService {
    
    protected $environment;
    protected $entityManager;
    
    public function __construct(SupUtilities $supUtilities, $environment, $entityManager)
    {
        $this->supUtilities = $supUtilities;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
    }
    
    /********************
     *      INSERTS     *
     * ******************/
    
    public function insertNewProductOrParticularity($row)
    {    
        try {
            $query = "INSERT INTO PARTFILI (CDPRODUTO, CDFILIAL, NRSEQPART, CDTIPPART, CDMARCA, CDFORNECED) VALUES (:CDPRODUTO, :CDFILIAL, :NRSEQPART, :CDTIPPART, :CDMARCA, :CDFORNECED)";
            $param = [
                'CDPRODUTO'  => $row['CDPRODUTO'],
                'CDFILIAL'   => $row['CDFILIAL'],
                'NRSEQPART'  => $row['NRSEQPART'],
                'CDTIPPART'  => $row['CDTIPPART'],
                'CDMARCA'    => $row['CDMARCA'],
                'CDFORNECED' => $row['CDFORNECED']
            ];
            return $this->supUtilities->crud($query, $param);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir período!');
        }
    }
    
    
    /********************
     *      UPDATES     *
     * ******************/
     
     
    public function updateParticularity($row)
    {
        try {
            $query = "UPDATE PARTFILI SET CDPRODUTO = :CDPRODUTO, CDFILIAL = :CDFILIAL, CDTIPPART = :CDTIPPART, CDMARCA = :CDMARCA, CDFORNECED = :CDFORNECED WHERE CDPRODUTO = :P_CDPRODUTO AND CDFILIAL = :P_CDFILIAL AND CDTIPPART = :P_CDTIPPART";
            $params = [
                'CDPRODUTO'   => $row['CDPRODUTO'],
                'CDFILIAL'    => $row['CDFILIAL'],
                'CDTIPPART'   => $row['CDTIPPART'],
                'CDMARCA'     => $row['CDMARCA'],
                'CDFORNECED'  => $row['CDFORNECED'],
                'P_CDPRODUTO' => $row['CDPRODUTO'],
                'P_CDFILIAL'  => $row['CDFILIAL'],
                'P_CDTIPPART' => $row['CDTIPPART']
            ];
            $this->supUtilities->crud($query, $params);
        } catch (Exception $e) {
            throw new \Exception('Erro ao atualizar período!');
        }
    }
    
    
    /********************
     *      DELETES     *
     * ******************/
     
    
    public function deleteProductOrParticularity($row)
    {
        try {
            $query = "DELETE FROM PARTFILI WHERE CDPRODUTO = :P_CDPRODUTO AND CDFILIAL = :P_CDFILIAL AND NRSEQPART = :P_NRSEQPART AND CDTIPPART = :P_CDTIPPART";
            $params = [
                'P_CDPRODUTO' => $row['CDPRODUTO'],
                'P_CDFILIAL'  => $row['CDFILIAL'],
                'P_NRSEQPART' => $row['NRSEQPART'],
                'P_CDTIPPART' => $row['CDTIPPART']
            ];
            $this->supUtilities->crud($query, $params);
        } catch (Exception $e) {
            throw new \Exception('Erro ao deletar unidade!');
        }
    }
    
    
    /********************
     *      SELECTS     *
     * ******************/
     
     

     
    public function validaProdutoExiste($row)
    {
        $query = "SELECT DISTINCT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO";
        $params = [
            'P_CDFILIAL'  => $row['CDFILIAL'],
            'P_CDPRODUTO' => $row['CDPRODUTO']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function getProductInformation($row)
    {
        $query = "SELECT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PARTFILI.CDTIPPART, PARTFILI.NRSEQPART, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO";
        $params = [
            'P_CDFILIAL'  => $row['CDFILIAL'],
            'P_CDPRODUTO' => $row['CDPRODUTO']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function validaMarcaProduto($row)
    {
        $query = "SELECT MAX(CDNVPRODUTO) AS SEARCHCDNVPRODUTO 
                    FROM PRODUTO";

        $params = [];
        $result = $this->supUtilities->crud($query, $params);
        $maxcdnvproduto = $result[0]['SEARCHCDNVPRODUTO'];
        
        if(isset($row['CDNVPRODUTO']) && $row['CDNVPRODUTO'] ===  $maxcdnvproduto) {
            $query = "SELECT MARCA.CDMARCA, MARCA.NMMARCA 
                        FROM MARCA 
                       WHERE MARCA.CDMARCA = :P_CDMARCA 
                         AND EXISTS (SELECT 1 
                                       FROM MARCPRODCOMP 
                                      WHERE :P_CDPRODUTO = MARCPRODCOMP.CDPRMARCOMPL 
                                        AND MARCA.CDMARCA = MARCPRODCOMP.CDMARCA)";
            $params = [
                'P_CDMARCA'   => $row['CDMARCA'],
                'P_CDPRODUTO' => $row['CDPRODUTO']
            ];
            
            return $this->supUtilities->crud($query, $params);
        } else {
            $query = "SELECT MARCA.CDMARCA, MARCA.NMMARCA 
                        FROM MARCA 
                       WHERE MARCA.CDMARCA = :P_CDMARCA 
                         AND EXISTS (SELECT 1 
                                       FROM PRODUTO, MARCPROD 
                                      WHERE PRODUTO.CDPRODUTO = MARCPROD.CDPRODUTO 
                                        AND ((PRODUTO.CDARVPROD LIKE :P_CDARVPROD || '%') OR (:P_CDARVPROD LIKE PRODUTO.CDARVPROD || '%')) 
                                        AND MARCPROD.CDMARCA = MARCA.CDMARCA)";
            $params = [
                'P_CDMARCA'   => $row['CDMARCA'],
                'P_CDARVPROD' => $row['CDARVPROD']
            ];
            
            return $this->supUtilities->crud($query, $params);
        }
    }
    
    public function getExistingBrandParticularities($row)
    {
        $query = "SELECT DISTINCT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PARTFILI.CDTIPPART, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO AND (PARTFILI.CDTIPPART <> :P_CDTIPPART OR PARTFILI.CDTIPPART = '1') AND PARTFILI.CDTIPPART <> '4' AND PARTFILI.CDTIPPART <> '5' AND PARTFILI.CDTIPPART <> '6'";
        $params = [
            'P_CDFILIAL'  => $row['CDFILIAL'],
            'P_CDPRODUTO' => $row['CDPRODUTO'],
            'P_CDTIPPART' => $row['CDTIPPART']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function particularitiesSelect($row)
    {
        $sql = "SELECT FILIAL.CDFILIAL, FILIAL.NMFILIAL, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDTIPPART, PARTFILI.CDGRUPPROD, FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN, MARCA.CDMARCA, MARCA.NMMARCA FROM PARTFILI INNER JOIN PRODUTO ON PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO INNER JOIN (SELECT FILIAL.CDFILIAL, FILIAL.NMFILIAL FROM FILIAL WHERE :P_CDGRUPFILI IS NULL AND (INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') UNION ALL SELECT FILIAL.CDFILIAL, FILIAL.NMFILIAL FROM FILIAL INNER JOIN FILGRUPFILI ON FILIAL.CDFILIAL = FILGRUPFILI.CDFILIAL WHERE FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI AND (INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') ) FILIAL ON PARTFILI.CDFILIAL = FILIAL.CDFILIAL LEFT JOIN MARCA ON PARTFILI.CDMARCA = MARCA.CDMARCA LEFT JOIN FORNECEDOR ON PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED, PARAMGERAL WHERE (PRODUTO.CDARVPROD BETWEEN :P_CDARVPRODINI AND :P_CDARVPRODFIN OR :P_TPRODUTO = 'T') AND INSTR(:P_CDTIPPART, PARTFILI.CDTIPPART) > 0 AND (INSTR(:P_CDMARCA, PARTFILI.CDMARCA) > 0 OR :P_CDMARCA = 'T') AND (INSTR(:P_CDFORNECED, PARTFILI.CDFORNECED) > 0 OR :P_CDFORNECED = 'T') ORDER BY FILIAL.CDFILIAL, PARTFILI.CDTIPPART, PRODUTO.CDARVPROD";
        $params =
            [
                'P_CDMARCA'      =>  $row['CDMARCA'],
                'P_CDARVPRODFIN' =>  str_pad($row['CDARVPRODFIN'], 20, 'Z', STR_PAD_RIGHT),
                'P_CDARVPRODINI' =>  $row['CDARVPRODINI'],
                'P_CDTIPPART'    =>  $row['CDTIPPART'],
                'P_CDFORNECED'   =>  $row['CDFORNECED'],
                'P_CDFILIAL'     =>  $row['CDFILIAL'],
                'P_CDGRUPFILI'   =>  $row['CDGRUPFILI'],
                'P_TPRODUTO'     =>  $row['TPRODUTO']
            ];
        return $this->supUtilities->crud($sql, $params);
    }
    
    public function getExistingProviderParticularities($row)
    {
        $query = "SELECT DISTINCT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PARTFILI.CDTIPPART, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO AND ( PARTFILI.CDTIPPART <> :P_CDTIPPART OR PARTFILI.CDTIPPART = '4' ) AND PARTFILI.CDTIPPART <> '1' AND PARTFILI.CDTIPPART <> '2' AND PARTFILI.CDTIPPART <> '3'";
        $params = [
            'P_CDFILIAL'  => $row['CDFILIAL'],
            'P_CDPRODUTO' => $row['CDPRODUTO'],
            'P_CDTIPPART' => $row['CDTIPPART']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function getExistingBrandProviderParticularities($row)
    {
        $query = "SELECT DISTINCT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PARTFILI.CDTIPPART, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO AND ( PARTFILI.CDTIPPART <> :P_CDTIPPART OR PARTFILI.CDTIPPART = '7' )";
        $params = [
            'P_CDFILIAL'  => $row['CDFILIAL'],
            'P_CDPRODUTO' => $row['CDPRODUTO'],
            'P_CDTIPPART' => $row['CDTIPPART']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function validateBrandExists($row)
    {
        $query = "SELECT DISTINCT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PARTFILI.CDTIPPART, MARCA.CDMARCA, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO AND PARTFILI.CDTIPPART = :P_CDTIPPART AND MARCA.CDMARCA = :P_CDMARCA";
        $params = [
            'P_CDFILIAL'  => $row['CDFILIAL'],
            'P_CDPRODUTO' => $row['CDPRODUTO'],
            'P_CDTIPPART' => $row['CDTIPPART'],
            'P_CDMARCA'   => $row['CDMARCA']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function validateProviderExists($row)
    {
        $query = "SELECT DISTINCT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PARTFILI.CDTIPPART, MARCA.CDMARCA, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO AND PARTFILI.CDTIPPART = :P_CDTIPPART AND FORNECEDOR.CDFORNECED = :P_CDFORNECED";
        $params = [
            'P_CDFILIAL'   => $row['CDFILIAL'],
            'P_CDPRODUTO'  => $row['CDPRODUTO'],
            'P_CDTIPPART'  => $row['CDTIPPART'],
            'P_CDFORNECED' => $row['CDFORNECED']
        ];
        
        return $this->supUtilities->crud($query, $params);
    }
    
    public function validateBrandProviderExists($row)
    {
        $query = "SELECT DISTINCT PARTFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PARTFILI.CDFILIAL, PARTFILI.CDTIPPART, MARCA.CDMARCA, PRODUTO.NRORG FROM MARCA, FORNECEDOR, PRODUTO, PARTFILI WHERE PARTFILI.CDFILIAL = :P_CDFILIAL AND PARTFILI.CDPRODUTO = PRODUTO.CDPRODUTO AND PARTFILI.CDMARCA = MARCA.CDMARCA (+) AND PARTFILI.CDFORNECED = FORNECEDOR.CDFORNECED (+) AND PRODUTO.CDPRODUTO = :P_CDPRODUTO AND PARTFILI.CDTIPPART = :P_CDTIPPART AND MARCA.CDMARCA = :P_CDMARCA AND FORNECEDOR.CDFORNECED = :P_CDFORNECED";
        $params = [
            'P_CDFILIAL'   => $row['CDFILIAL'],
            'P_CDPRODUTO'  => $row['CDPRODUTO'],
            'P_CDTIPPART'  => $row['CDTIPPART'],
            'P_CDMARCA'    => $row['CDMARCA'],
            'P_CDFORNECED' => $row['CDFORNECED']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function buscaParticularidade($row)
    {
        $query = "SELECT PF.CDFILIAL, PF.CDPRODUTO, P.NMPRODUTO, PF.CDTIPPART, PF.NRSEQPART, PF.CDMARCA, PF.CDFORNECED, P.CDARVPROD, P.CDNVPRODUTO
                   FROM PARTFILI PF, PRODUTO P
                  WHERE PF.CDFILCOTA    IS NULL
                    AND PF.NRCOLEPRECO  IS NULL
                    AND (PF.CDPRODUTO  =  P.CDPRODUTO)
                    AND ((P.CDARVPROD BETWEEN :P_CDARVPRODINI  AND :P_CDARVPRODFIN) OR :P_TPRODUTO = 'T')
                    AND (INSTR(:P_CDMARCA, PF.CDMARCA) <> 0 OR :P_CDMARCA = 'T')
                    AND (INSTR(:P_CDFORNECED, PF.CDFORNECED) <> 0 OR :P_CDFORNECED = 'T')
                    AND (INSTR(:P_CDTIPPART, PF.CDTIPPART)  <> 0)
                    AND (PF.CDFILIAL   =  :P_CDFILIALORIG)";
       $params = [
            'P_CDARVPRODINI' => $row['CDARVPRODINI'],
            'P_CDARVPRODFIN' => $row['CDARVPRODFIN'],
            'P_TPRODUTO'     => $row['TPRODUTO'],
            'P_CDMARCA'      => $row['CDMARCA'],
            'P_CDFORNECED'   => $row['CDFORNECED'],
            'P_CDTIPPART'    => $row['CDTIPPART'],
            'P_CDFILIALORIG' => $row['CDFILIORIG']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function buscaFilial($row)
    {
        $query = "SELECT F.CDFILIAL, F.NMFILIAL
                        FROM FILIAL F, FILIOPER FP
                       WHERE F.CDFILIAL    = FP.CDFILIAL
                         AND ((INSTR(:P_CDFILIAL, F.CDFILIAL) > 0) OR (:P_CDFILIAL = 'T'))
                         AND (FP.CDOPERADOR = :P_CDOPERADOR)
                         AND (F.CDFILIAL   <> :P_CDFILIALORIG)
                         AND (F.CDFILIAL    = FP.CDFILIAL)
                       ORDER BY F.CDFILIAL";
       $params = [
            'P_CDFILIAL'     => $row['CDFILIAL'],
            'P_CDOPERADOR'   => $row['CDOPERADOR'],
            'P_CDFILIALORIG' => $row['CDFILIORIG']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function buscaGrupoFilial($row)
    {
        $query = "SELECT F.CDFILIAL, F.NMFILIAL
                        FROM FILIAL F, FILIOPER FP
                       WHERE F.CDFILIAL    = FP.CDFILIAL
                         AND (FP.CDOPERADOR = :P_CDOPERADOR)
                         AND (F.CDFILIAL   <> :P_CDFILIALORIG)
                         AND (F.CDFILIAL    = FP.CDFILIAL)
                         AND (:P_CDGRUPFILI IS NULL OR EXISTS (SELECT 1
                                                                FROM FILGRUPFILI
                                                               WHERE FILGRUPFILI.CDFILIAL   = F.CDFILIAL
                                                                 AND FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI))
                       ORDER BY F.CDFILIAL";
       $params = [
            'P_CDOPERADOR'   => $row['CDOPERADOR'],
            'P_CDFILIALORIG' => $row['CDFILIORIG'],
            'P_CDGRUPFILI'   => $row['CDGRUPFILI']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function buscaMarca ($row){
        $query = "SELECT CDMARCA, NMMARCA
                   FROM MARCA
                  WHERE CDMARCA = :P_CDMARCA";
        $params = [
            'P_CDMARCA' => $row['CDMARCA']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function buscaFornecedor ($row){
        $query = "SELECT CDFORNECED, NMFANTFORN
                   FROM FORNECEDOR
                  WHERE CDFORNECED = :P_CDFORNECED";
        $params = [
            'P_CDFORNECED' => $row['CDFORNECED']
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    
    public function deleteSubstituir($filial, $item)
    {
        $query = "DELETE
                  FROM PARTFILI
                  WHERE PARTFILI.CDFILIAL = :P_CDFILIAL
                   AND PARTFILI.CDPRODUTO = :P_CDPRODUTO";
        $params = [
            'P_CDFILIAL'  => $filial['CDFILIAL'],
            'P_CDPRODUTO' => $item['CDPRODUTO']
        ];
        return $this->supUtilities->crud($query, $params);    
    }
    
    public function deleteClonar($filial, $row)
    {
        $query =  "DELETE
                    FROM PARTFILI
                   WHERE PARTFILI.CDFILIAL   =  :P_CDFILIAL
                     AND (INSTR(:P_CDMARCA, PARTFILI.CDMARCA) <> 0 OR :P_CDMARCA = 'T')
                     AND (INSTR(:P_CDFORNECED, PARTFILI.CDFORNECED) <> 0 OR :P_CDFORNECED = 'T')
                     AND EXISTS (SELECT 1
                                   FROM PRODUTO
                                  WHERE PRODUTO.CDPRODUTO  =  PARTFILI.CDPRODUTO
                                    AND ((PRODUTO.CDARVPROD BETWEEN :P_CDARVPRODINI AND :P_CDARVPRODFIN) OR :P_TPRODUTO = 'T'))";
        $params = [
            'P_CDFILIAL'     => $filial['CDFILIAL'],
            'P_CDMARCA'      => $row['CDMARCA'],
            'P_CDFORNECED'   => $row['CDFORNECED'],
            'P_CDARVPRODINI' => $row['CDARVPRODINI'],
            'P_CDARVPRODFIN' => $row['CDARVPRODFIN'],
            'P_TPRODUTO'     => $row['TPRODUTO'],
        ];
        return $this->supUtilities->crud($query, $params);    
    }
   
    
    /***********************
     *      PROCEDURES     *
     * *********************/
     
       
    public function procedureExcluirPartFili($row)
    {
        try {
            $connection = $this->entityManager->getConnection();
            $procedure = new StoredProcedure($connection, 'EXCLUIR_PARTFILI');
            
            $procedure->addParam(new Param('P_TPRODUTO',     Param::PARAM_INPUT, $row['TPRODUTO']));
            $procedure->addParam(new Param('P_CDPRODINI',    Param::PARAM_INPUT, $row['CDARVPRODINI']));
            $procedure->addParam(new Param('P_CDPRODFIN',    Param::PARAM_INPUT, $row['CDARVPRODFIN']));
            $procedure->addParam(new Param('P_CDFILIAL',     Param::PARAM_INPUT, $row['CDFILIAL']));
            $procedure->addParam(new Param('P_CDMARCA',      Param::PARAM_INPUT, $row['CDMARCA']));
            $procedure->addParam(new Param('P_CDFORNECED',   Param::PARAM_INPUT, $row['CDFORNECED']));
            $procedure->addParam(new Param('P_CDTIPPART',    Param::PARAM_INPUT, $row['CDTIPPART']));
            $procedure->addParam(new Param('P_CDGRUPFILI',   Param::PARAM_INPUT, $row['CDGRUPFILI']));
            $procedure->addParam(new Param('P_CDOPERADOR',   Param::PARAM_INPUT, $row['CDOPERADOR']));
            $procedure->addParam(new Param('P_CDFILIALORIG', Param::PARAM_INPUT, null));
            $procedure->addParam(new Param('P_COMMIT',       Param::PARAM_INPUT, 'S'));
            
            $procedure->execute();
        } catch(Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
        
    }
    
    public function procedureIncluiPartFili($row)
    {
        try {
            $connection = $this->entityManager->getConnection();
            $procedure = new StoredProcedure($connection, 'INCLUI_PARTFILI');
            
            $procedure->addParam(new Param('P_CDPRODINI',    Param::PARAM_INPUT, $row['CDARVPRODINI']));
            $procedure->addParam(new Param('P_CDPRODFIN',    Param::PARAM_INPUT, $row['CDARVPRODFIN']));
            $procedure->addParam(new Param('P_TPRODUTO',     Param::PARAM_INPUT, $row['TPRODUTO']));
            $procedure->addParam(new Param('P_CDFILIAL',     Param::PARAM_INPUT, $row['CDFILIAL']));
            $procedure->addParam(new Param('P_CDMARCA',      Param::PARAM_INPUT, $row['CDMARCA']));
            $procedure->addParam(new Param('P_CDFORNECED',   Param::PARAM_INPUT, $row['CDFORNECED']));
            $procedure->addParam(new Param('P_CDTIPPART',    Param::PARAM_INPUT, $row['CDTIPPART']));
            $procedure->addParam(new Param('P_CDGRUPFILI',   Param::PARAM_INPUT, $row['CDGRUPFILI']));
            $procedure->addParam(new Param('P_CDOPERADOR',   Param::PARAM_INPUT, $row['CDOPERADOR']));
            $procedure->addParam(new Param('P_CHECK',        Param::PARAM_INPUT, $row['IDACAOEXPORT']));
            $procedure->addParam(new Param('P_CDFILIALORIG', Param::PARAM_INPUT, $row['CDFILIORIG']));
            $procedure->addParam(new Param('P_ROWSAFFECT',   Param::PARAM_OUTPUT, null));
            
            return $procedure->execute();
        } catch(Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    
}