<?php

namespace Util\Firebase;

use Util\Firebase\FCMServiceInterface;
use Plokko\Firebase\ServiceAccount;
use Plokko\Firebase\FCM\Request;
use Plokko\Firebase\FCM\Message;
use Plokko\Firebase\FCM\Targets\Token;
use Plokko\Firebase\FCM\Exceptions\FcmErrorException;

class FCMService implements FCMServiceInterface
{

    protected $googleServicesFilePath;

    public function __construct($googleServicesFilePath)
    {
        $this->googleServicesFilePath = $googleServicesFilePath;
    }

    public function sendPushNotification($userToken, $payload)
    {
        $serviceAccount = new ServiceAccount(__DIR__ . "/" . $this->googleServicesFilePath);
        $data = isset($payload['data']) ? $payload['data'] : null;
        $message = $this->getNewMessage($userToken, $payload['title'], $payload['body'], $data);
        $request = new Request($serviceAccount);
        try {
            $message->send($request);
        } catch (FcmErrorException $fcmException) {
            throw $fcmException;
        }
    }

    protected function getNewMessage($userToken, $title, $body, $data = null)
    {
        $message = new Message();
        $message->notification->setTitle($title);
        $message->notification->setBody($body);
        $message->setTarget(new Token($userToken));
        if ($data !== null) {
            $message->data->fill($data);
        }
        return $message;
    }
}
